@@ -207,19 +207,14 @@ def volume_weighted_high_low_vol_cont(data = None,  contravariant = -1., lag = 2
     data['volu_hi_low_pct_rank'] = data['volu_hi_low'].rank(pct=True)
     data['close_ret_pct_rank'] = data['close_ret'].rank(pct=True)
 
-    trend_rank = data['close_ret_pct_rank'].iloc[-1]
-    vol_rank = data['volu_hi_low_pct_rank'].iloc[-1]
-
-
-
     #trend over the all lookback period
-    trend = ((data['close'][-1]-data['close'][0])/data['close'][0])
+    trend = ((data['close'].iloc[-1]-data['close'].iloc[0])/data['close'].iloc[0])
     # vol over the all lookback_period
     weighted_volu_hi_low = data['volu_hi_low'].sum() / data['volumefrom'].sum()
 
     #trend over the lagging period
-    trend_lag = ((data['close'][-1]-data['close'][-1])/data['close'][-1])
-    weighted_volu_hi_low_lag = data['volu_hi_low'][-1]/ data['volumefrom'][-1]
+    trend_lag = ((data['close'].iloc[-1]-data['close'].iloc[-2])/data['close'].iloc[-2])
+    weighted_volu_hi_low_lag = data['volu_hi_low'].iloc[-1]/ data['volumefrom'].iloc[-1]
 
     trend_ratio = trend_lag/trend
     vol_ratio = weighted_volu_hi_low_lag/weighted_volu_hi_low
